thorn.dispatch.base — Thorn 1.3.0 documentation

# thorn.dispatch.base

- thorn.dispatch.base

## thorn.dispatch.base

Default webhook dispatcher.

class `thorn.dispatch.base.` `Dispatcher`(timeout=None, app=None)
  `app` = None
  `dispatch_request`(request)
  `encode_cached`(payload, cache, ctype)
  `encode_payload`(data, content_type)
  `prepare_requests`(event, payload, sender, timeout=None, context=None, extra_subscribers=None, **kwargs)
  `send`(event, payload, sender, context=None, extra_subscribers=None, allow_keepalive=True, **kwargs)
  `subscribers_for_event`(name, sender=None, context={}, extra_subscribers=None)

    Return a list of `Subscriber` subscribing to an event by name (optionally filtered by sender).